@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, ConfigDict
 from typing import Optional, List, Any
 
 
@@ -40,8 +40,4 @@ class EditSessionState(BaseModel):
         1, description="Current iteration number in the edit session"
     )
 
-    class Config:
-        # Allow arbitrary types for flexibility with different object types
-        arbitrary_types_allowed = True
-        # Use enum values for serialization
-        use_enum_values = True
+    model_config = ConfigDict(arbitrary_types_allowed=True, use_enum_values=True)
